require 'wx'
include Wx

class PracticeConfig
    attr_accessor :status, :point, :guard, :counter, :ukemi, :okiagari
    attr_accessor :after_okiagari_flag, :after_okiagari_value, :after_okiagari_custom_command
    
    def initialize()
        @config_file = "practice.ini"
        
        @status = 0
        @point = 3
        @guard = 1
        @counter = 1
        @ukemi = 3
        @okiagari = 3
        @after_okiagari_flag = false
        @after_okiagari_value = Hash.new
        @after_okiagari_value['ground_stand'] = false
        @after_okiagari_value['ground_squat'] = false
        @after_okiagari_value['ground_front'] = false
        @after_okiagari_value['ground_back'] = false
        @after_okiagari_value['jump_up'] = false
        @after_okiagari_value['jump_front'] = false
        @after_okiagari_value['jump_back'] = false
        @after_okiagari_value['hj_up'] = false
        @after_okiagari_value['hj_front'] = false
        @after_okiagari_value['hj_back'] = false
        @after_okiagari_value['attack_A'] = false
        @after_okiagari_value['attack_2A'] = false
        @after_okiagari_value['attack_3A'] = false
        @after_okiagari_value['attack_6A'] = false
        @after_okiagari_value['attack_623B'] = false
        @after_okiagari_value['attack_623C'] = false
        @after_okiagari_value['custom'] = false
        @after_okiagari_custom_command = ""
    end
    
    def load()
        open(@config_file) { |file|
            file.each { |line|
#                print line
                if line=~/\A\s*practice_status\s*=\s*(\d+)\Z/ then
                    @status = $1.to_i
                elsif line=~/\A\s*practice_point\s*=\s*(\d+)\Z/ then
                    @point = $1.to_i
                elsif line=~/\A\s*practice_guard\s*=\s*(\d+)\Z/ then
                    @guard = $1.to_i
                elsif line=~/\A\s*practice_counter\s*=\s*(\d+)\Z/ then
                    @counter = $1.to_i
                elsif line=~/\A\s*practice_ukemi\s*=\s*(\d+)\Z/ then
                    @ukemi = $1.to_i
                elsif line=~/\A\s*practice_okiagari\s*=\s*(\d+)\Z/ then
                    @okiagari = $1.to_i
                elsif line=~/\A\s*practice_after_okiagari_flag\s*=\s*(\w+)\s*\Z/ then
                    @after_okiagari_flag = $1.to_i
                    if $1 == 'true' then
                        @after_okiagari_flag = true
                    elsif $1 == 'false' then
                        @after_okiagari_flag = false
                    end
                elsif line=~/\A\s*practice_after_okiagari_value\[\'(\w+)\'\]\s*=\s*(\w+)\Z/ then
                    if $2 == 'true' then
                        @after_okiagari_value[$1] = true
                    elsif $2 == 'false' then
                        @after_okiagari_value[$1] = false
                    end
                elsif line=~/\A\s*practice_after_okiagari_custom_command\s*=\s*\"(\S*)\"\Z/ then
                    @after_okiagari_custom_command = $1
                end
            }
        }
    end
    
    def save()
        open(@config_file, 'w') { |f|
            f.print "practice_status = ", @status, "\n"
            f.print "practice_point = ", @point, "\n"
            f.print "practice_guard = ", @guard, "\n"
            f.print "practice_counter = ", @counter, "\n"
            f.print "practice_ukemi = ", @ukemi, "\n"
            f.print "practice_okiagari = ", @okiagari, "\n"
            f.print "practice_after_okiagari_flag = ", @after_okiagari_flag, "\n"
            f.print "practice_after_okiagari_value = {}\n"
            f.print "practice_after_okiagari_value['ground_stand'] = ", @after_okiagari_value['ground_stand'], "\n"
            f.print "practice_after_okiagari_value['ground_squat'] = ", @after_okiagari_value['ground_squat'], "\n"
            f.print "practice_after_okiagari_value['ground_front'] = ", @after_okiagari_value['ground_front'], "\n"
            f.print "practice_after_okiagari_value['ground_back'] = ", @after_okiagari_value['ground_back'], "\n"
            f.print "practice_after_okiagari_value['jump_up'] = ", @after_okiagari_value['jump_up'], "\n"
            f.print "practice_after_okiagari_value['jump_front'] = ", @after_okiagari_value['jump_front'], "\n"
            f.print "practice_after_okiagari_value['jump_back'] = ", @after_okiagari_value['jump_back'], "\n"
            f.print "practice_after_okiagari_value['hj_up'] = ", @after_okiagari_value['hj_up'], "\n"
            f.print "practice_after_okiagari_value['hj_front'] = ", @after_okiagari_value['hj_front'], "\n"
            f.print "practice_after_okiagari_value['hj_back'] = ", @after_okiagari_value['hj_back'], "\n"
            f.print "practice_after_okiagari_value['attack_A'] = ", @after_okiagari_value['attack_A'], "\n"
            f.print "practice_after_okiagari_value['attack_2A'] = ", @after_okiagari_value['attack_2A'], "\n"
            f.print "practice_after_okiagari_value['attack_3A'] = ", @after_okiagari_value['attack_3A'], "\n"
            f.print "practice_after_okiagari_value['attack_6A'] = ", @after_okiagari_value['attack_6A'], "\n"
            f.print "practice_after_okiagari_value['attack_623B'] = ", @after_okiagari_value['attack_623B'], "\n"
            f.print "practice_after_okiagari_value['attack_623C'] = ", @after_okiagari_value['attack_623C'], "\n"
            f.print "practice_after_okiagari_value['custom'] = ", @after_okiagari_value['custom'], "\n"
            f.print "practice_after_okiagari_custom_command = \"", @after_okiagari_custom_command, "\"\n"
        }
    end
end